@@ -40,7 +40,7 @@
  *  \param[in] labely Etiqueta del eje Y: Lineas.
  *  \param[in] labelz Etiqueta del eje Z: Altura.
  *  \param[in] octfile Nombre del archivo *.m de octave que se usará de intermediario.
- *  Si ostfile==NULL entonces se creará un fichero con nombre aleatorio y se 
+ *  Si octfile==NULL entonces se creará un fichero con nombre aleatorio y se 
  *  borrará al terminar de crear el archivo de imagen.
  *  \param[in] imgfile Nombre del archivo de imagen generado. 
  *  El tipo de archivo es seleccionado por la extensión del nombre imgfile.
@@ -132,7 +132,7 @@ int pds_octave_surf_matrix(const PdsMatrix *M,const char *labelx,const char *lab
  *  \param[in] labelx Etiqueta del eje X: Columnas.
  *  \param[in] labely Etiqueta del eje Y: Lineas.
  *  \param[in] octfile Nombre del archivo *.m de octave que se usará de intermediario.
- *  Si ostfile==NULL entonces se creará un fichero con nombre aleatorio y se 
+ *  Si octfile==NULL entonces se creará un fichero con nombre aleatorio y se 
  *  borrará al terminar de crear el archivo de imagen.
  *  \param[in] imgfile Nombre del archivo de imagen generado. 
  *  El tipo de archivo es seleccionado por la extensión del nombre imgfile.
@@ -215,11 +215,9 @@ int pds_octave_pcolor_matrix(const PdsMatrix *M,const char *labelx,const char *l
  *  <center>
  *  \image html pds_octave_imwrite_matrix.png "Usando la función imwrite() de Octave."
  *  </center>
- *  \param[in] M Matriz a imprimir. Esta matriz debe tener elements entre 0 y 1.
- *  \param[in] labelx Etiqueta del eje X: Columnas.
- *  \param[in] labely Etiqueta del eje Y: Lineas.
+ *  \param[in] M Matriz a imprimir. Esta matriz debe tener elementos entre 0 y 1.
  *  \param[in] octfile Nombre del archivo *.m de octave que se usará de intermediario.
- *  Si ostfile==NULL entonces se creará un fichero con nombre aleatorio y se 
+ *  Si octfile==NULL entonces se creará un fichero con nombre aleatorio y se 
  *  borrará al terminar de crear el archivo de imagen.
  *  \param[in] imgfile Nombre del archivo de imagen generado. 
  *  El tipo de archivo es seleccionado por la extensión del nombre imgfile.
@@ -293,7 +291,7 @@ int pds_octave_imwrite_matrix(const PdsMatrix *M,const char *octfile,const char
  *  \param[in] labelx Etiqueta del eje X.
  *  \param[in] labely Etiqueta del eje Y.
  *  \param[in] octfile Nombre del archivo *.m de octave que se usará de intermediario.
- *  Si ostfile==NULL entonces se creará un fichero con nombre aleatorio y se 
+ *  Si octfile==NULL entonces se creará un fichero con nombre aleatorio y se 
  *  borrará al terminar de crear el archivo de imagen.
  *  \param[in] imgfile Nombre del archivo de imagen generado. 
  *  El tipo de archivo es seleccionado por la extensión del nombre imgfile.
@@ -379,7 +377,7 @@ int pds_octave_plot_vector(const PdsVector *V,const char *labelx,const char *lab
  *  \param[in] labelx Etiqueta del eje X.
  *  \param[in] labely Etiqueta del eje Y.
  *  \param[in] octfile Nombre del archivo *.m de octave que se usará de intermediario.
- *  Si ostfile==NULL entonces se creará un fichero con nombre aleatorio y se 
+ *  Si octfile==NULL entonces se creará un fichero con nombre aleatorio y se 
  *  borrará al terminar de crear el archivo de imagen.
  *  \param[in] imgfile Nombre del archivo de imagen generado. 
  *  El tipo de archivo es seleccionado por la extensión del nombre imgfile.
@@ -480,7 +478,7 @@ int pds_octave_plot_vectors(const PdsVector *X,const PdsVector *Y,const char *la
  *  \param[in] legendu Legenda de U.
  *  \param[in] legendv Legenda de V.
  *  \param[in] octfile Nombre del archivo *.m de octave que se usará de intermediario.
- *  Si ostfile==NULL entonces se creará un fichero con nombre aleatorio y se 
+ *  Si octfile==NULL entonces se creará un fichero con nombre aleatorio y se 
  *  borrará al terminar de crear el archivo de imagen.
  *  \param[in] imgfile Nombre del archivo de imagen generado. 
  *  El tipo de archivo es seleccionado por la extensión del nombre imgfile.
@@ -538,7 +536,7 @@ int pds_octave_plot_compare_vectors(const PdsVector *X,const PdsVector *U,const
     	fprintf(fd,"];\n");
     }
 	fprintf(fd,"h=figure(1);\n");// h=figure('Visible', 'off');
-	fprintf(fd,"plot(X,U,\'o-\',X,V,\'s-\');\n");
+	fprintf(fd,"plot(X,U,\'o-\',X,V,\'>-\');\n");
 	fprintf(fd,"grid on;\n");
 	fprintf(fd,"hx=xlabel(\'%s\');\n",labelx);
 	fprintf(fd,"hy=ylabel(\'%s\');\n",labely);
@@ -586,7 +584,7 @@ int pds_octave_plot_compare_vectors(const PdsVector *X,const PdsVector *U,const
  *  \param[in] labelx Etiqueta del eje X.
  *  \param[in] labely Etiqueta del eje Y.
  *  \param[in] octfile Nombre del archivo *.m de octave que se usará de intermediario.
- *  Si ostfile==NULL entonces se creará un fichero con nombre aleatorio y se 
+ *  Si octfile==NULL entonces se creará un fichero con nombre aleatorio y se 
  *  borrará al terminar de crear el archivo de imagen.
  *  \param[in] imgfile Nombre del archivo de imagen generado. 
  *  El tipo de archivo es seleccionado por la extensión del nombre imgfile.
@@ -673,7 +671,7 @@ int pds_octave_plot_file_col(const char *datafile,int col,const char *labelx,con
  *  \param[in] labelx Etiqueta del eje X.
  *  \param[in] labely Etiqueta del eje Y.
  *  \param[in] octfile Nombre del archivo *.m de octave que se usará de intermediario.
- *  Si ostfile==NULL entonces se creará un fichero con nombre aleatorio y se 
+ *  Si octfile==NULL entonces se creará un fichero con nombre aleatorio y se 
  *  borrará al terminar de crear el archivo de imagen.
  *  \param[in] imgfile Nombre del archivo de imagen generado. 
  *  El tipo de archivo es seleccionado por la extensión del nombre imgfile.
