@@ -30,6 +30,6 @@
 #define __PDSOCTPLOT_H__
 
 
-#include <pds/pdsoctplotpng.h>
+#include <pds/pdsoctave.h>
 
 #endif /* __PDSOCTPLOT_H__ */
